Fidus Writer
============

Fidus Writer is an online collaborative editor especially made for academics who need to use citations and/or formulas. The editor focuses on the content rather than the layout, so that with the same text, you can later on publish it in multiple ways: On a website, as a printed book, or as an ebook. In each case, you can choose from a number of layouts that are adequate for the medium of choice.


[![Fidus Writer](https://snapcraft.io/fiduswriter/badge.svg)](https://snapcraft.io/fiduswriter)

[![Coverage Status](https://coveralls.io/repos/github/fiduswriter/fiduswriter/badge.svg?branch=main)](https://coveralls.io/github/fiduswriter/fiduswriter?branch=main)

[![Bountysource](https://www.bountysource.com/badge/tracker?tracker_id=328497)](https://www.bountysource.com/trackers/328497-fiduswriter?utm_source=328497&utm_medium=shield&utm_campaign=TRACKER_BADGE)


Installation
------------

Installation procedures can be found in our [WIKI](https://github.com/fiduswriter/fiduswriter/wiki/).


Contributing
------------

For details on contributing, please check http://fiduswriter.org/help-us/ .


License
-------

All of Fidus Writer's original code is licensed under the GNU AFFERO GENERAL PUBLIC LICENSE, for details see LICENSE. Some third party libraries are licensed under other, compatible open source libraries. Licensing information is included in those files.
